Re-exports
pub use multipart::Multipart;
Modules
Macros
- impl_
post_ parseable_ for_ custom_ type - Helper macro for users to implement PostParseableFromStr for their custom types
Structs
Enums
Traits
- Post
Parseable - Trait for types that can be parsed from multipart form data
- Post
Parseable From Str - Trait for types that can be parsed from multipart form data.